darkhistory.utilities.spence_series_diff — DarkHistory documentation

# darkhistory.utilities.spence_series_diff

`darkhistory.utilities.` `spence_series_diff`(b, a)

  Returns the Taylor series for Li2(b) - Li2(a).

  Li2 is the polylogarithm function defined by

  \[\text{Li}_2(z) \equiv \sum_{k=1}^\infty \frac{z^k}{k^2} \,.\]

  Parameters: | a : ndarray Input for Li2(a). b : ndarray Input for Li2(b).
  Returns: | ndarray The Taylor series Li2(b) - Li2(a), up to the 11th order term.

#### Previous topic

darkhistory.utilities.log_series_diff

#### Next topic

darkhistory.utilities.Interpolator2D

### This Page

Show Source